==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/databox/kotlin/inputs/PreferencesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databox.kotlin.inputs

import com.pulumi.azurenative.databox.inputs.PreferencesArgs.builder
import com.pulumi.azurenative.databox.kotlin.enums.StorageAccountAccessTier
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Preferences related to the order
 * @property encryptionPreferences Preferences related to the Encryption.
 * @property preferredDataCenterRegion Preferred data center region.
 * @property reverseTransportPreferences Optional Preferences related to the reverse shipment logistics of the sku.
 * @property storageAccountAccessTierPreferences Preferences related to the Access Tier of storage accounts.
 * @property transportPreferences Preferences related to the shipment logistics of the sku.
 */
public data class PreferencesArgs(
    public val encryptionPreferences: Output<EncryptionPreferencesArgs>? = null,
    public val preferredDataCenterRegion: Output<List<String>>? = null,
    public val reverseTransportPreferences: Output<TransportPreferencesArgs>? = null,
    public val storageAccountAccessTierPreferences:
    Output<List<Either<String, StorageAccountAccessTier>>>? = null,
    public val transportPreferences: Output<TransportPreferencesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.databox.inputs.PreferencesArgs> {
    override fun toJava(): com.pulumi.azurenative.databox.inputs.PreferencesArgs =
        com.pulumi.azurenative.databox.inputs.PreferencesArgs.builder()
            .encryptionPreferences(
                encryptionPreferences?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .preferredDataCenterRegion(
                preferredDataCenterRegion?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .reverseTransportPreferences(
                reverseTransportPreferences?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .storageAccountAccessTierPreferences(
                storageAccountAccessTierPreferences?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 ->
                            args0.let({ args0 ->
                                args0.toJava()
                            })
                        })
                    })
                }),
            )
            .transportPreferences(
                transportPreferences?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [PreferencesArgs].
 */
@PulumiTagMarker
public class PreferencesArgsBuilder internal constructor() {
    private var encryptionPreferences: Output<EncryptionPreferencesArgs>? = null

    private var preferredDataCenterRegion: Output<List<String>>? = null

    private var reverseTransportPreferences: Output<TransportPreferencesArgs>? = null

    private var storageAccountAccessTierPreferences:
        Output<List<Either<String, StorageAccountAccessTier>>>? = null

    private var transportPreferences: Output<TransportPreferencesArgs>? = null

    /**
     * @param value Preferences related to the Encryption.
     */
    @JvmName("qhdrybrwellxulkx")
    public suspend fun encryptionPreferences(`value`: Output<EncryptionPreferencesArgs>) {
        this.encryptionPreferences = value
    }

    /**
     * @param value Preferred data center region.
     */
    @JvmName("flmahduqguytcxqp")
    public suspend fun preferredDataCenterRegion(`value`: Output<List<String>>) {
        this.preferredDataCenterRegion = value
    }

    @JvmName("ipkivblnpqqklhqr")
    public suspend fun preferredDataCenterRegion(vararg values: Output<String>) {
        this.preferredDataCenterRegion = Output.all(values.asList())
    }

    /**
     * @param values Preferred data center region.
     */
    @JvmName("wdgxwxvfchlmyqtu")
    public suspend fun preferredDataCenterRegion(values: List<Output<String>>) {
        this.preferredDataCenterRegion = Output.all(values)
    }

    /**
     * @param value Optional Preferences related to the reverse shipment logistics of the sku.
     */
    @JvmName("ynngphfenmnxlecw")
    public suspend fun reverseTransportPreferences(`value`: Output<TransportPreferencesArgs>) {
        this.reverseTransportPreferences = value
    }

    /**
     * @param value Preferences related to the Access Tier of storage accounts.
     */
    @JvmName("dcgjrelxraywnvsi")
    public suspend
    fun storageAccountAccessTierPreferences(`value`: Output<List<Either<String, StorageAccountAccessTier>>>) {
        this.storageAccountAccessTierPreferences = value
    }

    @JvmName("evykmbqmsnkwbfrm")
    public suspend fun storageAccountAccessTierPreferences(
        vararg
        values: Output<Either<String, StorageAccountAccessTier>>,
    ) {
        this.storageAccountAccessTierPreferences = Output.all(values.asList())
    }

    /**
     * @param values Preferences related to the Access Tier of storage accounts.
     */
    @JvmName("tsnnstfttrxkpuoo")
    public suspend
    fun storageAccountAccessTierPreferences(values: List<Output<Either<String, StorageAccountAccessTier>>>) {
        this.storageAccountAccessTierPreferences = Output.all(values)
    }

    /**
     * @param value Preferences related to the shipment logistics of the sku.
     */
    @JvmName("hyficgfsnkhsjwui")
    public suspend fun transportPreferences(`value`: Output<TransportPreferencesArgs>) {
        this.transportPreferences = value
    }

    /**
     * @param value Preferences related to the Encryption.
     */
    @JvmName("mpieeqdbopfhwlll")
    public suspend fun encryptionPreferences(`value`: EncryptionPreferencesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.encryptionPreferences = mapped
    }

    /**
     * @param argument Preferences related to the Encryption.
     */
    @JvmName("mqodphrlqodkxdxw")
    public suspend
    fun encryptionPreferences(argument: suspend EncryptionPreferencesArgsBuilder.() -> Unit) {
        val toBeMapped = EncryptionPreferencesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.encryptionPreferences = mapped
    }

    /**
     * @param value Preferred data center region.
     */
    @JvmName("botrogdvcqduafol")
    public suspend fun preferredDataCenterRegion(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.preferredDataCenterRegion = mapped
    }

    /**
     * @param values Preferred data center region.
     */
    @JvmName("xranlhnjiffwigjv")
    public suspend fun preferredDataCenterRegion(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.preferredDataCenterRegion = mapped
    }

    /**
     * @param value Optional Preferences related to the reverse shipment logistics of the sku.
     */
    @JvmName("jgqsftdsonglylpb")
    public suspend fun reverseTransportPreferences(`value`: TransportPreferencesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.reverseTransportPreferences = mapped
    }

    /**
     * @param argument Optional Preferences related to the reverse shipment logistics of the sku.
     */
    @JvmName("juopwvynyivxmxol")
    public suspend
    fun reverseTransportPreferences(argument: suspend TransportPreferencesArgsBuilder.() -> Unit) {
        val toBeMapped = TransportPreferencesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.reverseTransportPreferences = mapped
    }

    /**
     * @param value Preferences related to the Access Tier of storage accounts.
     */
    @JvmName("bsxwnbrgjiqwbpsd")
    public suspend
    fun storageAccountAccessTierPreferences(`value`: List<Either<String, StorageAccountAccessTier>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountAccessTierPreferences = mapped
    }

    /**
     * @param values Preferences related to the Access Tier of storage accounts.
     */
    @JvmName("toajddgobievmigt")
    public suspend fun storageAccountAccessTierPreferences(
        vararg
        values: Either<String, StorageAccountAccessTier>,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.storageAccountAccessTierPreferences = mapped
    }

    /**
     * @param value Preferences related to the shipment logistics of the sku.
     */
    @JvmName("oduvwqfjvcdwssao")
    public suspend fun transportPreferences(`value`: TransportPreferencesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.transportPreferences = mapped
    }

    /**
     * @param argument Preferences related to the shipment logistics of the sku.
     */
    @JvmName("vixctbyqexpdmuqe")
    public suspend
    fun transportPreferences(argument: suspend TransportPreferencesArgsBuilder.() -> Unit) {
        val toBeMapped = TransportPreferencesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.transportPreferences = mapped
    }

    internal fun build(): PreferencesArgs = PreferencesArgs(
        encryptionPreferences = encryptionPreferences,
        preferredDataCenterRegion = preferredDataCenterRegion,
        reverseTransportPreferences = reverseTransportPreferences,
        storageAccountAccessTierPreferences = storageAccountAccessTierPreferences,
        transportPreferences = transportPreferences,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/databox/kotlin/inputs/PreferencesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databox.kotlin.inputs

import com.pulumi.azurenative.databox.inputs.PreferencesArgs.builder
import com.pulumi.azurenative.databox.kotlin.enums.StorageAccountAccessTier
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Preferences related to the order
 * @property encryptionPreferences Preferences related to the Encryption.
 * @property preferredDataCenterRegion Preferred data center region.
 * @property reverseTransportPreferences Optional Preferences related to the reverse shipment logistics of the sku.
 * @property storageAccountAccessTierPreferences Preferences related to the Access Tier of storage accounts.
 * @property transportPreferences Preferences related to the shipment logistics of the sku.
 */
public data class PreferencesArgs(
    public val encryptionPreferences: Output<EncryptionPreferencesArgs>? = null,
    public val preferredDataCenterRegion: Output<List<String>>? = null,
    public val reverseTransportPreferences: Output<TransportPreferencesArgs>? = null,
    public val storageAccountAccessTierPreferences:
    Output<List<Either<String, StorageAccountAccessTier>>>? = null,
    public val transportPreferences: Output<TransportPreferencesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.databox.inputs.PreferencesArgs> {
    override fun toJava(): com.pulumi.azurenative.databox.inputs.PreferencesArgs =
        com.pulumi.azurenative.databox.inputs.PreferencesArgs.builder()
            .encryptionPreferences(
                encryptionPreferences?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .preferredDataCenterRegion(
                preferredDataCenterRegion?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0
                    })
                }),
            )
            .reverseTransportPreferences(
                reverseTransportPreferences?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .storageAccountAccessTierPreferences(
                storageAccountAccessTierPreferences?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 -> args0 }, { args0 ->
                            args0.let({ args0 ->
                                args0.toJava()
                            })
                        })
                    })
                }),
            )
            .transportPreferences(
                transportPreferences?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [PreferencesArgs].
 */
@PulumiTagMarker
public class PreferencesArgsBuilder internal constructor() {
    private var encryptionPreferences: Output<EncryptionPreferencesArgs>? = null

    private var preferredDataCenterRegion: Output<List<String>>? = null

    private var reverseTransportPreferences: Output<TransportPreferencesArgs>? = null

    private var storageAccountAccessTierPreferences:
        Output<List<Either<String, StorageAccountAccessTier>>>? = null

    private var transportPreferences: Output<TransportPreferencesArgs>? = null

    /**
     * @param value Preferences related to the Encryption.
     */
    @JvmName("gywwpjvuscrdfddi")
    public suspend fun encryptionPreferences(`value`: Output<EncryptionPreferencesArgs>) {
        this.encryptionPreferences = value
    }

    /**
     * @param value Preferred data center region.
     */
    @JvmName("rhkggsscfhjanuye")
    public suspend fun preferredDataCenterRegion(`value`: Output<List<String>>) {
        this.preferredDataCenterRegion = value
    }

    @JvmName("yrmpqfuayiugtdjr")
    public suspend fun preferredDataCenterRegion(vararg values: Output<String>) {
        this.preferredDataCenterRegion = Output.all(values.asList())
    }

    /**
     * @param values Preferred data center region.
     */
    @JvmName("urhmnuqgpuwravyu")
    public suspend fun preferredDataCenterRegion(values: List<Output<String>>) {
        this.preferredDataCenterRegion = Output.all(values)
    }

    /**
     * @param value Optional Preferences related to the reverse shipment logistics of the sku.
     */
    @JvmName("grcsdywqedgxefqb")
    public suspend fun reverseTransportPreferences(`value`: Output<TransportPreferencesArgs>) {
        this.reverseTransportPreferences = value
    }

    /**
     * @param value Preferences related to the Access Tier of storage accounts.
     */
    @JvmName("cyvprlpnklwgvujg")
    public suspend
    fun storageAccountAccessTierPreferences(`value`: Output<List<Either<String, StorageAccountAccessTier>>>) {
        this.storageAccountAccessTierPreferences = value
    }

    @JvmName("iqgbqiaigyoghcki")
    public suspend fun storageAccountAccessTierPreferences(
        vararg
        values: Output<Either<String, StorageAccountAccessTier>>,
    ) {
        this.storageAccountAccessTierPreferences = Output.all(values.asList())
    }

    /**
     * @param values Preferences related to the Access Tier of storage accounts.
     */
    @JvmName("hrywdijkikajqfrm")
    public suspend
    fun storageAccountAccessTierPreferences(values: List<Output<Either<String, StorageAccountAccessTier>>>) {
        this.storageAccountAccessTierPreferences = Output.all(values)
    }

    /**
     * @param value Preferences related to the shipment logistics of the sku.
     */
    @JvmName("rsmipoxilafrpojv")
    public suspend fun transportPreferences(`value`: Output<TransportPreferencesArgs>) {
        this.transportPreferences = value
    }

    /**
     * @param value Preferences related to the Encryption.
     */
    @JvmName("ggqilefkykwlbned")
    public suspend fun encryptionPreferences(`value`: EncryptionPreferencesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.encryptionPreferences = mapped
    }

    /**
     * @param argument Preferences related to the Encryption.
     */
    @JvmName("hulsrjxedelhokxm")
    public suspend
    fun encryptionPreferences(argument: suspend EncryptionPreferencesArgsBuilder.() -> Unit) {
        val toBeMapped = EncryptionPreferencesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.encryptionPreferences = mapped
    }

    /**
     * @param value Preferred data center region.
     */
    @JvmName("vaewyqnlxgvehtmm")
    public suspend fun preferredDataCenterRegion(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.preferredDataCenterRegion = mapped
    }

    /**
     * @param values Preferred data center region.
     */
    @JvmName("sesghuuuxeqgltrb")
    public suspend fun preferredDataCenterRegion(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.preferredDataCenterRegion = mapped
    }

    /**
     * @param value Optional Preferences related to the reverse shipment logistics of the sku.
     */
    @JvmName("ifxauetfhyaxoeeb")
    public suspend fun reverseTransportPreferences(`value`: TransportPreferencesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.reverseTransportPreferences = mapped
    }

    /**
     * @param argument Optional Preferences related to the reverse shipment logistics of the sku.
     */
    @JvmName("gjgvaokckxwqnfar")
    public suspend
    fun reverseTransportPreferences(argument: suspend TransportPreferencesArgsBuilder.() -> Unit) {
        val toBeMapped = TransportPreferencesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.reverseTransportPreferences = mapped
    }

    /**
     * @param value Preferences related to the Access Tier of storage accounts.
     */
    @JvmName("atxfefmmaeuoxubw")
    public suspend
    fun storageAccountAccessTierPreferences(`value`: List<Either<String, StorageAccountAccessTier>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountAccessTierPreferences = mapped
    }

    /**
     * @param values Preferences related to the Access Tier of storage accounts.
     */
    @JvmName("vfaxvyuqnspjcgav")
    public suspend fun storageAccountAccessTierPreferences(
        vararg
        values: Either<String, StorageAccountAccessTier>,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.storageAccountAccessTierPreferences = mapped
    }

    /**
     * @param value Preferences related to the shipment logistics of the sku.
     */
    @JvmName("jereklwjstsbqjtt")
    public suspend fun transportPreferences(`value`: TransportPreferencesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.transportPreferences = mapped
    }

    /**
     * @param argument Preferences related to the shipment logistics of the sku.
     */
    @JvmName("rqmyceerjvjadnmg")
    public suspend
    fun transportPreferences(argument: suspend TransportPreferencesArgsBuilder.() -> Unit) {
        val toBeMapped = TransportPreferencesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.transportPreferences = mapped
    }

    internal fun build(): PreferencesArgs = PreferencesArgs(
        encryptionPreferences = encryptionPreferences,
        preferredDataCenterRegion = preferredDataCenterRegion,
        reverseTransportPreferences = reverseTransportPreferences,
        storageAccountAccessTierPreferences = storageAccountAccessTierPreferences,
        transportPreferences = transportPreferences,
    )
}
